==> plugin-xrea-1.0.zip: plugin-xrea-1.0/plugin/xrea.pl <==
######################################################################
# xrea.inc.pl - This is PyukiWiki, yet another Wiki clone.
# $Id: xrea.pl,v 1.23 2006/03/06 00:51:13 papu Exp $
#
# "xrea plugin" version 1.0 $$
# Author: Nanami http://lineage.netgamers.jp/
# Copyright (C) 2004-2006 by Nekyo.
# http://nekyo.hp.infoseek.co.jp/
# Copyright (C) 2005-2006 PyukiWiki Developers Team
# http://pyukiwiki.sourceforge.jp/
# Based on YukiWiki http://www.hyuki.com/yukiwiki/
# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
# License: GPL2 and/or Artistic or each later version
#
# This program is free software; you can redistribute it and/or
# modify it under the same terms as Perl itself.
# Return:LF Code=EUC-JP 1TAB=4Spaces
######################################################################
#
# xrea.comѹХʡϥץ饰
#
# ˡ
#
# index.cgi  index.xcg  ĥ xcg ѹޤ
# (.cgiξϡưˤʤޤ)
# 
# ȼɥᥤꤷƤʤ
# &xrea([left][center][right]);
# xrea.comΥСǤСưŪ˽Ϥޤ
# 
# ȼɥᥤꤷƤ
# xrea̤ǡHTMLǧơ󥵥֥ɥᥤǧޤ
# &xrea([left][center][right],username.s??.xrea.com);
#  xrea.comΥСǤСưŪ˽Ϥޤ
#
# 
# ֤ϡɬ1280x1024ԥβ̤Ǹƥ뤹ɬ
# ʤ֡פɽ褦ˤƲ
# http://sb.xrea.com/showthread.php?t=10009
#
# ":Header" ڡɤǤ礦
#
# xrea+ͭСξϡϤפǤ
#
# ռ''ưåΤ''̵ǥڡߤĺ
#  xrea.comͤ˴פޤ
#
######################################################################

use strict;
package xrea;

sub plugin_block {
	return &plugin_inline;
}

sub plugin_inline {
	my $body;
	my $hostname;
	my @args = split(/,/, shift);
	my $div=$args[0];
	if($args[1] ne '') {
		$hostname=$args[1];
		if($hostname!~/xrea\.com$/) {
			return qq(<strong>xrea.pl error!</strong> '$hostname' not allowed<br />);
		}
		if($ENV{SERVER_ADMIN}!~/xrea\.com$/ || $ENV{SCRIPT_FILENAME}!~/\.xcg$/) {
			return ' ';
		}
	} else {
		$hostname=$ENV{HTTP_HOST};
		if($ENV{SERVER_NAME}!~/xrea\.com$/ || $ENV{SCRIPT_FILENAME}!~/\.xcg$/) {
			return ' ';
		}
	}
	$body=<<EOM;
@{[$div eq '' ? '' : qq(<div align="$div">)]}
<script type="text/javascript" src="http://imgj.xrea.com/xa.j?site=$hostname"></script>
<noscript><iframe height="60" width="468" frameborder="0" marginheight="0" marginwidth="0" scrolling="no" allowtransparency="true" src="http://img.xrea.com/ad_iframe.fcg?site=$hostname"><a href="http://img.xrea.com/ad_click.fcg?site=$hostname" target="_blank"><img src="http://img.xrea.com/ad_img.fcg?site=$hostname" border="0" alt="xreaad"></a></iframe></noscript>
@{[$div eq '' ? '' : qq(</div>)]}
EOM
	return $body;
}

sub plugin_usage {
	return {
		name => 'xrea',
		version => '1.0',
		author => 'Nanami <http://lineage.netgamers.jp/>',
		syntax => '&xrea(your hostname);',
		description => 'xrea.com AD plugin.',
		example => '&xrea(your hostname);',
	};
}

1;
__END__

=head1 NAME

xrea.pl - PyukiWiki / YukiWiki Plugin

=head1 WARNING

=over 4

=item CANNOT UNDERSTAND JAPANESE, MUST NOT USE THIS PLUGIN!!

From xrea.com

 The minimum qualification conditions...
 He lives in Japan, and understands Japanese, and it can respond.

=item Visit to xrea.com (Japanese)

L<http://xrea.com/>

=back

=head1 SYNOPSIS

 &xrea;
 #xrea
 &xrea(align, xrea's your subdomain);

=head1 DESCRIPTION

In the free rental server of xrea.com, an advertising banner is displayed on arbitrary positions.

=head1 USAGE

Please look at the upper part of the page of a plugin file or japanese pod file.

=head1 SEE ALSO

=over 4

=item PyukiWiki/Plugin/Nanami/xrea

L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/xrea/>

=item PyukiWiki CVS

L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin/xrea.pl>

=back

=head1 AUTHOR

=over 4

=item Nanami

L<http://lineage.netgamers.jp/> etc...

=item PyukiWiki Developers Team

L<http://pyukiwiki.sourceforge.jp/>

=back

=head1 LICENSE

Copyright (C) 2005-2006 by Nanami.

Copyright (C) 2005-2006 by PyukiWiki Developers Team

License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.

This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut

==> plugin-xrea-1.1.zip: plugin-xrea-1.1/plugin/xrea.pl <==
######################################################################
# xrea.pl - This is PyukiWiki, yet another Wiki clone.
# $Id: xrea.pl,v 1.47 2012/01/30 15:16:28 papu Exp $
#
# "xrea" version 1.1 $$
# Author: Nanami http://nanakochi.daiba.cx/
# Copyright (C) 2004-2012 Nekyo
# http://nekyo.qp.land.to/
# Copyright (C) 2005-2012 PyukiWiki Developers Team
# http://pyukiwiki.sfjp.jp/
# Based on YukiWiki http://www.hyuki.com/yukiwiki/
# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
# License: GPL3 and/or Artistic or each later version
#
# This program is free software; you can redistribute it and/or
# modify it under the same terms as Perl itself.
# Return:LF Code=Shift-JIS 1TAB=4Spaces
######################################################################
# xrea.comѹХʡϥץ饰
#
# ˡ
#
# index.cgi  index.xcg  ĥ xcg ѹޤ
# (.cgiξϡưˤʤޤ)
#
# ȼɥᥤꤷƤʤ
# &xrea([left][center][right]);
# xrea.comΥСǤСưŪ˽Ϥޤ
#
# ȼɥᥤꤷƤ
# xrea̤ǡHTMLǧơ󥵥֥ɥᥤǧޤ
# &xrea([left][center][right],username.s??.xrea.com);
#  xrea.comΥСǤСưŪ˽Ϥޤ
#
# 
# ֤ϡɬ1280x1024ԥβ̤Ǹƥ뤹ɬ
# ʤ֡פɽ褦ˤƲ
# http://sb.xrea.com/showthread.php?t=10009
#
# ":Header" ڡɤǤ礦
#
# xrea+ͭСξϡϤפǤ
#
# ռ''ưåΤ''̵ǥڡߤĺ
# ޤ xrea.comͤ˴פޤ
######################################################################

$PLUGIN="xrea";
$VERSION="1.1";

use strict;
package xrea;

sub plugin_block {
	return &plugin_inline;
}

sub plugin_inline {
	my $body;
	my $hostname;
	my @args = split(/,/, shift);
	my $div=$args[0];
	if($args[1] ne '') {
		$hostname=$args[1];
		if($hostname!~/xrea\.com$/) {
			return qq(<strong>xrea.pl error!</strong> '$hostname' not allowed<br />);
		}
		if($ENV{SERVER_ADMIN}!~/xrea\.com$/ || $ENV{SCRIPT_FILENAME}!~/\.xcg$/) {
			return ' ';
		}
	} else {
		$hostname=$ENV{HTTP_HOST};
		if($ENV{SERVER_NAME}!~/xrea\.com$/ || $ENV{SCRIPT_FILENAME}!~/\.xcg$/) {
			return ' ';
		}
	}
	$body=<<EOM;
@{[$div eq '' ? '' : qq(<div align="$div">)]}
<script type="text/javascript" src="http://imgj.xrea.com/xa.j?site=$hostname"></script>
<noscript><iframe height="60" width="468" frameborder="0" marginheight="0" marginwidth="0" scrolling="no" allowtransparency="true" src="http://img.xrea.com/ad_iframe.fcg?site=$hostname"><a href="http://img.xrea.com/ad_click.fcg?site=$hostname" target="_blank"><img src="http://img.xrea.com/ad_img.fcg?site=$hostname" border="0" alt="xreaad"></a></iframe></noscript>
@{[$div eq '' ? '' : qq(</div>)]}
EOM
	return $body;
}

sub plugin_usage {
	return {
		name => 'xrea',
		version => '1.0',
		author => 'Nanami <http://www.daiba.cx/>',
		syntax => '&xrea(your hostname);',
		description => 'xrea.com AD plugin.',
		example => '&xrea(your hostname);',
	};
}

1;
__END__

=head1 NAME

xrea.pl - PyukiWiki / YukiWiki Plugin

=head1 WARNING

=over 4

=item CANNOT UNDERSTAND JAPANESE, MUST NOT USE THIS PLUGIN!!

From xrea.com

 The minimum qualification conditions...
 He lives in Japan, and understands Japanese, and it can respond.

=item Visit to xrea.com (Japanese)

L<http://xrea.com/>

=back

=head1 SYNOPSIS

 &xrea;
 #xrea
 &xrea(align, xrea's your subdomain);

=head1 DESCRIPTION

In the free rental server of xrea.com, an advertising banner is displayed on arbitrary positions.

=head1 USAGE

Please look at the upper part of the page of a plugin file or japanese pod file.

=head1 SEE ALSO

=over 4

=item PyukiWiki/Plugin/Nanami/xrea

L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Nanami/xrea/>

=item PyukiWiki CVS

L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/xrea.pl?view=log>

L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/xrea.pl?view=log>

=back

=head1 AUTHOR

=over 4

=item Nanami

L<http://nanakochi.daiba.cx/> etc...

=item PyukiWiki Developers Team

L<http://pyukiwiki.sfjp.jp/>

=back

=head1 LICENSE

Copyright (C) 2005-2012 by Nanami.

Copyright (C) 2005-2012 by PyukiWiki Developers Team

License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.

This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut
